# vim: set sw=4 ts=4 et:
#
# spec file for package aircrack-ng
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without unstable
%bcond_without sqlite
%define pkg_version 1.2-beta1

Name:           aircrack-ng
Version:        1.2.beta1
Release:        1.1
License:        GPL-2.0
Summary:        Aircrack-ng is the next generation of aircrack
Url:            http://www.aircrack-ng.org/
Group:          Productivity/Networking/Security
# no source because of legal problems in Germany where mirrors are located
# marguerite: still valid? 
Source:        http://download.aircrack-ng.org/%{name}-%{pkg_version}.tar.gz
Source1:        README.SUSE
Patch:         aircrack-ng-1.2-remove_usr_local.patch
BuildRequires:  gcc-c++
BuildRequires:	libgcrypt-devel
%if 0%{?suse_version} <= 1140
BuildRequires:  libnl-devel
%else
BuildRequires:	libnl3-devel
%endif
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:	sqlite3-devel
BuildRequires:	zlib-devel
Requires:	wireless-tools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Aircrack-ng is the next generation of aircrack with lots of new features:
 * Better documentation (wiki, manpages) and support
 * More cards/drivers supported
 * More OS and platforms supported
 * New WEP attack: PTW
 * WEP dictionary attack
 * Fragmentation attack
 * WPA Migration mode
 * Improved cracking speed
 * Capture with multiple cards
 * Optimizations, other improvements and bug fixing

%prep
%setup -q -n aircrack-ng-%{pkg_version}
find patches/ -type f -exec sed -i 's|\r||g' {} \;
cp "%{SOURCE1}" .
%patch -p1

%build
CFLAGS="%{optflags} -Wall" \
make \
        %{?_smp_mflags} \
        SQLITE=%{?with_sqlite:true}%{?!with_sqlite:false} \
        UNSTABLE=%{?with_unstable:true}%{?!with_unstable:false} \
	    gcrypt=true \
	    libnl=true \
        prefix="%{_prefix}" \
        libdir="%{_libdir}" \
        docdir="%{_docdir}/%{name}"

%install
%makeinstall \
        SQLITE=%{?with_sqlite:true}%{?!with_sqlite:false} \
        UNSTABLE=%{?with_unstable:true}%{?!with_unstable:false} \
        ext_scripts=true \
	    gcrypt=true \
	    libnl=true \
        sbindir="%{_sbindir}" \
        bindir="%{_bindir}" \
	    smandir="%{_mandir}/man8" \
        mandir="%{_mandir}/man1" \
        libdir="%{_libdir}" \
        docdir="%{_docdir}/%{name}"

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog LICENSE LICENSE.OpenSSL README README.md README.SUSE
%doc patches
%{_bindir}/aircrack-ng
%{_bindir}/airdecap-ng
%{_bindir}/airdecloak-ng
%{_bindir}/ivstools
%{_bindir}/kstats
%{_bindir}/makeivs-ng
%{_bindir}/packetforge-ng
%{_bindir}/wpaclean
%{_bindir}/versuck-ng
%{_sbindir}/airbase-ng
%{_sbindir}/airdriver-ng
%{_sbindir}/aireplay-ng
%{_sbindir}/airmon-ng
%{_sbindir}/airmon-zc
%{_sbindir}/airodump-ng
%{_sbindir}/airodump-ng-oui-update
%{_sbindir}/airserv-ng
%{_sbindir}/airtun-ng
%{_sbindir}/besside-ng
%if %{with sqlite}
%{_bindir}/airolib-ng
%endif
%if %{with unstable}
%{_bindir}/buddy-ng
%{_sbindir}/easside-ng
%{_sbindir}/tkiptun-ng
%{_sbindir}/wesside-ng
%endif
%doc %{_mandir}/man1/*.1%{ext_man}
%doc %{_mandir}/man8/*.8%{ext_man}

%changelog
* Sat Aug 31 2013 i@margueirte.su
- update version 1.2-beta1
  * see http://www.aircrack-ng.org/doku.php?id=changelog for details
- enable:
  * gcrypt: Use libgcrypt crypto library instead of the default OpenSSL
    And also use internal fast sha1 implementation
  * libnl: Add support for netlink (nl80211)
  * ext_scripts: airoscript-ng, versuck-ng, airgraph-ng and airdrop-ng
* Sun Apr 25 2010 pascal.bleser@opensuse.org
- update to 1.1
* Fri Oct 23 2009 pascal.bleser@opensuse.org
- forced rebuild to avoid uploading the binary packages
* Tue Sep  8 2009 pascal.bleser@opensuse.org
- update to 1.0
* Thu Sep  3 2009 pascal.bleser@opensuse.org
- update to rc4
* Thu Apr 16 2009 pascal.bleser@opensuse.org
- changed version to include rc3, final will be 1.0+final
- pass %%%%optflags properly
- spec file cleanup
- update to rc3
* Thu Jul 17 2008 andrea@links2linux.de
- First spec Making
